@@ -73,13 +73,16 @@ check.boolean <- function(b) # b==0 or b==1 is also ok
 }
 check.classname <- function(object, substituted.object, expected.classname)
 {
+    err.msg <- quotify(expected.classname)
+    if(length(expected.classname) > 1)
+        err.msg <- sprintf("one of\n%s", err.msg)
     if(is.null(object))
-        stopf("object is NULL (expected an object of class \"%s\")",
-              expected.classname)
+        stopf("object is NULL but expected an object of class of %s",
+              err.msg)
     if(!inherits(object, expected.classname)) {
-        stopf("the class of '%s' is \"%s\" but expected the class to be \"%s\"",
+        stopf("the class of '%s' is \"%s\" but expected the class to be %s",
               paste.trunc(substituted.object, maxlen=30),
-              class(object)[1], expected.classname)
+              class(object)[1], err.msg)
     }
 }
 check.integer.scalar <- function(object, min=NULL, max=NULL, null.ok=FALSE,
@@ -290,8 +293,10 @@ eval.trace <- function(
     eval(expr, envir, enclos)
 }
 # This function is used for xlim and ylim.
-# If xlim[1] == xlim[2], then plot() issues a message.  We don't want that,
-# so use this function to make sure xlim[2] is different to xlim[1].
+# This checks that lim is is a 2 element numeric vector.
+# Also, if xlim[1] == xlim[2], then plot() issues a confusing message.
+# We don't want that, so use this function to make sure xlim[2]
+# is different to xlim[1].
 
 fix.lim <- function(lim)
 {
@@ -309,6 +314,8 @@ fix.lim <- function(lim)
 
 gen.colnames <- function(x, prefix="x", alt.prefix=prefix, trace=0, xname=NULL)
 {
+    if(NCOL(x) == 0)
+        return(NULL)
     # If prefix is long and has characters like ( or [ then use the
     # alternate prefix.  This is sometimes necessary when prefix is
     # generated using deparse and the arg is something like
@@ -442,13 +449,17 @@ grepany <- function(pattern, x, ignore.case=FALSE, ...)
 # returns an index, choices is a vector of strings
 imatch.choices <- function(arg, choices,
             argname=short.deparse(substitute(arg), "function"),
-            err.msg.has.index=FALSE) # TRUE if integer "arg" is legal elsewhere
+            err.msg.has.index=FALSE, # TRUE if integer "arg" is legal elsewhere
+            err.msg="",              # error message, "" for automatic
+            err.msg.ext="")          # extension to error message
 {
-    if(!is.character(arg) || length(arg) != 1 || !nzchar(arg))
-         stopf("illegal '%s' argument\nChoose%s one of: %s",
-               argname,
+    err.msg.ext <- paste0(
                if(err.msg.has.index) " an integer index or" else "",
-               quotify(choices))
+               if(nchar(err.msg.ext)) paste0(" ", err.msg.ext, " or") else "")
+    if(nchar(err.msg) == 0)
+        err.msg <- sprintf("Choose%s one of: %s", err.msg.ext, quotify(choices))
+    if(!is.character(arg) || length(arg) != 1 || !nzchar(arg))
+         stopf("illegal '%s' argument\n%s", argname, err.msg)
     imatch <- pmatch(arg, choices)
     if(anyNA(imatch)) {
         imatch <- NULL
@@ -458,20 +469,14 @@ imatch.choices <- function(arg, choices,
         if(length(imatch) == 0) {
             if(length(choices) == 1)
                 stopf("%s=\"%s\" is not allowed\n       Only%s %s is allowed",
-                      argname, paste(arg),
-                      if(err.msg.has.index) " 1 or" else "",
-                      quotify(choices))
+                      argname, paste(arg), err.msg.ext, quotify(choices))
             else
-                stopf("%s=\"%s\" is not allowed\nChoose%s one of %s",
-                      argname, paste(arg),
-                      if(err.msg.has.index) " an integer index or" else "",
-                      quotify(choices))
+                stopf("%s=\"%s\" is not allowed\n%s",
+                      argname, paste(arg), err.msg)
         }
         if(length(imatch) > 1)
-            stopf("%s=\"%s\" is ambiguous\nChoose%s one of %s",
-                  argname, paste(arg),
-                  if(err.msg.has.index) " an integer index or" else "",
-                  quotify(choices))
+            stopf("%s=\"%s\" is ambiguous\n%s",
+                  argname, paste(arg), err.msg)
     }
     imatch
 }
@@ -484,12 +489,36 @@ is.integral <- function(object)
 
 is.specified <- function(object)
 {
-    !is.null(object) && !anyNA(object) && !identical(object, 0)
+    !is.null(object) && !anyNA(object) && !identical(object, 0) &&
+    # following needed for e.g. col=c("red", 0) because 0 is converted to string
+    !identical(object, "0") && !identical(object, "NA")
 }
 is.try.err <- function(object)
 {
     class(object)[1] == "try-error"
 }
+# Lighten color by amount 0 ... 1 where 1 is white.
+# If amount is negative, then darken the color, -1 is black.
+
+lighten <- function(col, lighten.amount, alpha=1)
+{
+    # stopifnot.scalar(lighten.amount)
+    # stopifnot(lighten.amount >= -1 && lighten.amount <= 1)
+    rgb <- col2rgb(col) / 255
+    # empirically, sqrt makes visual effect of lighten.amount more linear
+    lighten.amount2 <- sqrt(abs(lighten.amount))
+    rgb <-
+        if(lighten.amount > 0)
+            rgb + lighten.amount2 * (c(1,1,1) - rgb) # move each r,g,b towards 1
+        else # darken
+            rgb - lighten.amount2 * rgb              # move each r,g,b towards 0
+    rgb[rgb < 0] <- 0 # clamp
+    rgb[rgb > 1] <- 1
+    if(alpha == 1)
+        rgb(rgb[1,], rgb[2,], rgb[3,])
+    else
+        rgb(rgb[1,], rgb[2,], rgb[3,], alpha)
+}
 # returns the expanded arg
 match.arg1 <- function(arg, argname=deparse(substitute(arg)))
 {
@@ -498,9 +527,14 @@ match.arg1 <- function(arg, argname=deparse(substitute(arg)))
     formal.argnames[imatch.choices(arg[1], formal.argnames, argname)]
 }
 # returns a string, choices is a vector of strings
-match.choices <- function(arg, choices, argname=deparse(substitute(arg)))
+match.choices <- function(arg,
+            choices,
+            argname=deparse(substitute(arg)),
+            err.msg="",              # error message, "" for automatic
+            err.msg.ext="")          # extension to error message
 {
-    choices[imatch.choices(arg, choices, argname)]
+    choices[imatch.choices(arg, choices, argname,
+                           err.msg=err.msg, err.msg.ext=err.msg.ext)]
 }
 # This uses the object's .Environment attribute, which was
 # pre-assigned to the object via get.model.env
@@ -564,6 +598,8 @@ nlines <- function(s)
 {
     if(!nzchar(s[1])) # special case, caption="" is not printed
         0
+    else if(anyNA(s))
+        0
     else
         length(strsplit(s, "\n")[[1]])
 }
@@ -594,18 +630,6 @@ pastef <- function(s, fmt, ...) # paste the printf style args to s
 {
     paste0(s, sprintf(fmt, ...))
 }
-pt.cex <- function(ncases, npoints=ncases)
-{
-    n <- if(npoints > 0) min(npoints, ncases) else ncases
-
-    if     (n >= 20000) .2
-    else if(n >=  5000) .3
-    else if(n >=  3000) .4
-    else if(n >=  1000) .6
-    else if(n >=  300)  .8
-    else if(n >=  30)   1
-    else                1.2
-}
 print.first.few.elements.of.vector <- function(x, trace, name=NULL)
 {
     try(cat(" min", min(x), "max", max(x)), silent=TRUE)
@@ -659,6 +683,18 @@ printf.wrap <- function(fmt, ..., exdent=NULL, maxlen=2000)
     if(nchar(s) > i) for(j in nchar(s):i) # print trailing newlines
         if(substr(s, j, j) == "\n") cat0("\n") else break
 }
+pt.cex <- function(ncases, npoints=ncases)
+{
+    n <- if(npoints > 0) min(npoints, ncases) else ncases
+
+    if     (n >= 20000) .2
+    else if(n >=  5000) .3
+    else if(n >=  3000) .4
+    else if(n >=  1000) .6
+    else if(n >=  300)  .8
+    else if(n >=  30)   1
+    else                1.2
+}
 # like short.deparse but quotify the deparsed obj (unless the alternative is used)
 quote.deparse <- function(object, alternative="object")
 {
@@ -716,8 +752,16 @@ range1 <- function(object, ...)
     else
         range(object, finite=TRUE, ...)
 }
+recycle <- function(object, ref.object)
+{
+    repl(object, length.out=length(ref.object))
+}
 repl <- function(object, length.out)
 {
+    # following "if" added for R-2.15.3 otherwise
+    # get warning: 'x' is NULL so the result will be NULL
+    if(is.null(object))
+        return(NULL)
     check.numeric.scalar(length.out)
     stopifnot(floor(length.out) == length.out)
     stopifnot(length.out > 0)
@@ -793,11 +837,12 @@ text.on.white <- function(x, y, label,
     height      <- strheight(label, cex=cex, font=font)
     char.height <- strheight("X",   cex=cex, font=font)
     if(srt == 0) {
-        rect(x - adj[1]     * width  - xmar * char.width,
-             y - adj[2]     * height - .3   * char.height, # .3 for extra space at bottom
-             x + (1-adj[1]) * width  + xmar * char.width,
-             y + (1-adj[2]) * height + .1   * char.height,
-             col=white, border=NA)
+        if(is.specified(label))
+            rect(x - adj[1]     * width  - xmar * char.width,
+                 y - adj[2]     * height - .3   * char.height, # .3 for extra space at bottom
+                 x + (1-adj[1]) * width  + xmar * char.width,
+                 y + (1-adj[2]) * height + .1   * char.height,
+                 col=white, border=NA)
         text(x=x, y=y, labels=label, cex=cex, adj=adj, font=font, ...)
     } else if(srt == 90 || srt == -90) {
         # width and height are in usr coords, adjust these for flip of coords
@@ -808,11 +853,12 @@ text.on.white <- function(x, y, label,
         width  <- yrange / xrange * width
         char.height <- xrange / yrange * char.height
         char.width  <- yrange / xrange * char.width
-        rect(x + (1-adj[1]) * height,                    # left
-             y + (1-adj[2]) * width + xmar * char.width, # bottom
-             x - adj[1]     * height,                    # right
-             y - adj[2]     * width - xmar * char.width, # top
-             col=white, border=NA)
+        if(is.specified(label))
+            rect(x + (1-adj[1]) * height,                    # left
+                 y + (1-adj[2]) * width + xmar * char.width, # bottom
+                 x - adj[1]     * height,                    # right
+                 y - adj[2]     * width - xmar * char.width, # top
+                 col=white, border=NA)
         text(x=x, y=y, labels=label, cex=cex, adj=adj, font=font, srt=srt, ...)
     }
     else
